/***********************************************************************************************************************************
Repository Remove Command
***********************************************************************************************************************************/
#ifndef COMMAND_STORAGE_REMOVE_H
#define COMMAND_STORAGE_REMOVE_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Remove paths/files from the repository
FN_EXTERN void cmdStorageRemove(void);

#endif
